api

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2026 License: BSD-3-Clause Imports: 41 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	SettingsProvider     SettingsProvider
	DockerClientProvider DockerClientProvider
	RegistryAuthProvider RegistryAuthProvider
	Logger               *slog.Logger
}

Config configures Service.

type DockerClientProvider

type DockerClientProvider = types.DockerClientProvider

DockerClientProvider provides Docker clients.

type RegistryAuthProvider

type RegistryAuthProvider = types.RegistryAuthProvider

RegistryAuthProvider provides registry credentials owned by the host application.

type Service

type Service struct {
	// contains filtered or unexported fields
}

func NewBuilder

func NewBuilder(settings types.SettingsProvider, dockerClientProvider types.DockerClientProvider, registryAuthProvider types.RegistryAuthProvider) *Service

NewBuilder constructs a build service from the legacy positional dependencies.

func NewService

func NewService(config Config) *Service

NewService constructs a build service.

func (*Service) BuildImage

func (b *Service) BuildImage(ctx context.Context, req types.BuildRequest, progressWriter io.Writer, _ string) (*types.BuildResult, error)

type SettingsProvider

type SettingsProvider = types.SettingsProvider

SettingsProvider provides build settings owned by the host application.

Jump to